function [y2,perf]=OELM_Predict(NetDef,W1,W2,X,Y)
% Prediction of the network output
% 
% Usage       - [y2,perf]=OELM_Predict(NetDef,W1,W2,X,Y)
%
% Input:
% NetDef      - Network configuration:
%                   The activation functions must be either linear or logsig. The network
%                   architecture is defined by the matrix 'NetDef' consisting of two
%                   rows. The first row specifies the hidden layer while the second
%                   specifies the output layer.
%
%                   E.g.,    NetDef = ['LSSSS'
%                                     'L----']
%
%                       (L = Linear, S = logsig)
%
% W1          - Matrix of input weights and bias (Number of hidden neurons x Number of Input +1)
% W2          - Vector of output weights
% X           - Input matrix (Number of inputs x Number of samples)
% Y           - Output vector (1 x Number os samples)
%
% Output: 
% y2          - Predicted output
% perf        - RMSE accuracy
%                          
%
    %%%%    Author:    Tiago Matias
    %%%%    Institute of Systems and Robotics, Coimbra, Portugal
    %%%%    EMAIL:      tmatias@isr.uc.pt
    %%%%    WEBSITE:    http://www.isr.uc.pt/~tmatias/
    %%%%    DATE:       July 2013


[~,N] = size(Y);
L_hidden = find(NetDef(1,:)=='L')';   % Location of linear hidden units
H_hidden = find(NetDef(1,:)=='S')';   % Location of tanh hidden units
[hidden,~] = size(W1);
y1       = zeros(hidden,N);

% ---  Compute network output ---
h1 = W1*[X;ones(1,N)];
y1(H_hidden,:) = logsig(h1(H_hidden,:));
y1(L_hidden,:) = h1(L_hidden,:);

y2 = W2*y1;

% ---  Compute the performance ---
perf=sqrt(mse(y2-Y));

function t=logsig(x)
t= 1 ./ (1 + exp(-1*x));
